/* Automatically generated by po2tbl.sed from weex.pot.  */

#if HAVE_CONFIG_H
# include <config.h>
#endif

#include "libgettext.h"

const struct _msg_ent _msg_tbl[] = {
  {"", 1},
  {"Rebuilding cache file `%s'.\n", 2},
  {"Cache file `%s' does not exist.", 3},
  {" Creating a new one.\n", 4},
  {"Cache file `%s' is broken at line %d.\n", 5},
  {"Internal error: cache facility is broken.\n", 6},
  {"Cannot create cache file `%s'.\n", 7},
  {"Configuration file `%s/.weex/weexrc' does not exist.\n", 8},
  {"There is no section in configuration file.\n", 9},
  {"Cannot make directory `%s'.\n", 10},
  {"Created directory `%s'.\n", 11},
  {"Cannot get file status: `%s'\n", 12},
  {"A `default' section is required.\n", 13},
  {"\
When you set ChangePermissionDir, you must configure ChangePermission.\n", 14},
  {"Cannot expand symbolic link `%s'. Ignore this file.\n", 15},
  {"Expanding symbolic link failed: %s", 16},
  {"ConvToLower causes a conflict between `%s' and `%s'. Proceed anyway.\n", 17},
  {"Confliction by ConvToLower: %s", 18},
  {"Cannot create a unique file name.\n", 19},
  {"Cannot get remote directory list.\n", 20},
  {"Getting remote directory list failed", 21},
  {"Cannot open `%s'.\n", 22},
  {"Cannot remove `%s'.\n", 23},
  {"Cannot get the remote directory list correctly.\n", 24},
  {"           : %ld/%ld (%ld%%) [ ", 25},
  {"Complete: sent %d file(s), removed %d file(s)", 26},
  {"Specified host (section) name `%s' is undefined.\n", 27},
  {"Specified host (section) number `%s' is undefined.\n", 28},
  {"Cannot specify a default configuration.\n", 29},
  {"The source directory (SrcDir) is not configured.\n", 30},
  {"The destination directory (DestDir) is not configured.\n", 31},
  {"The host name is not configured.\n", 32},
  {"\
Cannot connect host `%s'.\n\
\n", 33},
  {"Connection failed: %s (%s)", 34},
  {"Connected: %s (%s)", 35},
  {"Disconnected: %s (%s)", 36},
  {"The login name is not configured.\n", 37},
  {"No password specified in configuration file for `%s'. Asking ...\n", 38},
  {"Password:", 39},
  {"\
Login failed. Check your ID and password.\n\
\n", 40},
  {"Login failed: %s (%s)", 41},
  {"Cannot change %s current working directory to `%s'.\n", 42},
  {"local", 43},
  {"remote", 44},
  {"Changing %s current working directory failed: %s", 45},
  {"Sent: %s%s", 46},
  {"Cannot change the access permissions of `%s%s' to `%s'.\n", 47},
  {"Changing the access permissions failed: %s%s", 48},
  {"Cannot send file `%s%s'.\n", 49},
  {"Sending failed: %s%s", 50},
  {"Retry to send: %s%s", 51},
  {"Retrying...\n", 52},
  {"%s : sent %d file(s), removed %d file(s)", 53},
  {"Cannot remove remote file `%s%s'.\n", 54},
  {"Removing failed: %s%s", 55},
  {"Removed: %s%s", 56},
  {"Cannot remove remote directory `%s%s/'.\n", 57},
  {"Removing failed: %s%s/", 58},
  {"Cannot make remote directory `%s%s/'.\n", 59},
  {"Making directory failed: %s%s/", 60},
  {"Connect    : ", 61},
  {"Disconnect : ", 62},
  {"Entering   : ", 63},
  {"Leaving    : ", 64},
  {"Sending    : ", 65},
  {"Changing   : ", 66},
  {"Removing   : ", 67},
  {"Making Dir : ", 68},
  {"Processing : ", 69},
  {"Configuration file `%s' is not found.\n", 70},
  {"Creating configuration file `%s' fails.\n", 71},
  {"\
%s(%d): %s\n\
Syntax error\n", 72},
  {"\
%s(%d): %s\n\
Unrecognized parameter\n", 73},
  {"\
%s(%d): %s\n\
Internal error\n", 74},
  {"\
%s(%d): %s\n\
Invalid number\n", 75},
  {"\
%s(%d): %s\n\
Out of range\n", 76},
  {"\
%s(%d): %s\n\
Cannot allocate memory.\n", 77},
  {"\
%s(%d): %s\n\
It must be specified TRUE or FALSE.\n", 78},
  {"\
%s(%d): %s\n\
The section name is already used.\n", 79},
  {"\
%s(%d)\n\
There is no closing brace.\n", 80},
  {"\
%s(%d): %s\n\
Unexplained error\n", 81},
  {"invalid number `%s'\n", 82},
  {"number `%s' to `%s' out of range\n", 83},
  {"unrecognized option `%s'\n", 84},
  {"option `%s' requires an argument\n", 85},
  {"option `%s' doesn't allow an argument\n", 86},
  {"unrecognized option `-%c'\n", 87},
  {"Cannot allocate memory.\n", 88},
  {"Invalid wildcard `%s'.\n", 89},
  {"\
Warning! Configuration file `%s/.weex/weexrc' does not exist.\n\
\n", 90},
  {"\
Fast Webpage Exchanger Ver %s Copyright (C) 1999-2000 Yuuki NINOMIYA\n\
\n\
This is free software with ABSOLUTELY NO WARRANTY.\n\
For details please see the file COPYING.\n\
\n\
usage: weex [OPTIONS] HOST...\n\
\n\
options:\n\
  -h | --help           display this help and exit\n\
  -s | --silent         suppress normal non-error messages\n\
  -f | --force          force sending all files\n\
  -m | --monochrome     output messages in monochrome\n\
  -t | --test           not modify remote files\n\
  -r | --rebuild-cache  rebuild cache file\n\
  -d | --debug-config   display configuration of each hosts\n\
  -D | --debug-ftplib   output debugging information for ftplib\n\
  -V | --version        display version information and exit\n\
\n", 91},
  {"Fast Webpage Exchanger Ver %s Copyright (C) 1999-2000 Yuuki NINOMIYA\n", 92},
  {"Cannot get a host name. Proceed anyway.\n", 93},
  {"Stopped.\n", 94},
  {"\
Log file `%s' seems to be always locked.\n\
Remove lock file `%s'.\n", 95},
  {"Another weex is using log file `%s'. Just a moment.\n", 96},
  {"Jan", 97},
  {"Feb", 98},
  {"Mar", 99},
  {"Apr", 100},
  {"May", 101},
  {"Jun", 102},
  {"Jul", 103},
  {"Aug", 104},
  {"Sep", 105},
  {"Oct", 106},
  {"Nov", 107},
  {"Dec", 108},
  {"%s %2d %02d:%02d:%02d %s weex[%d]: %s\n", 109},
};

int _msg_tbl_length = 109;
